==> deepin-font-installer_1.0.4.orig.tar.xz: deepin-font-installer-1.0.4/deepin-font-installer/translations/deepin-font-installer_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>HomePage</name>
    <message>
        <source>Drag font file here</source>
        <translation>Yazı tipini buraya sürükleyin</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Dosya seç</translation>
    </message>
</context>
<context>
    <name>ListItem</name>
    <message>
        <source>Installed</source>
        <translation>Yüklendi</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Diğer sürüm yüklü: %1</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Yükleme</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Aynı sürüm yüklü</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Deepin Yazı Tipi Yükleyici</translation>
    </message>
    <message>
        <source>Deepin Font Installer is used to install and uninstall font file for users with bulk install function.</source>
        <translation>Deepin Yazı Tipi Yükleyici kullanıcılar için yazı tipi dosyası yükleme ve kaldırma ile birlikte toplu yükleme işlevi kullanıldı.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Deepin Yazı Tipi Yükleyici</translation>
    </message>
    <message>
        <source>Bulk Install</source>
        <translation>Toplu Yükle</translation>
    </message>
</context>
<context>
    <name>MultiFilePage</name>
    <message>
        <source>Install</source>
        <translation>Yükle</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Başarıyla yüklendi</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Yazı tipi dizinini görüntüle</translation>
    </message>
    <message>
        <source>Refreshing font cache, please wait...</source>
        <translation>Yazı tipi önbelleği yenileniyor, lütfen bekleyiniz...</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Bilinmeyen</translation>
    </message>
</context>
<context>
    <name>SingleFilePage</name>
    <message>
        <source>Install</source>
        <translation>Yükle</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Yeniden Yükle</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Yazı tipi dizinini görüntüle</translation>
    </message>
    <message>
        <source>Style: </source>
        <translation>Biçem:</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Tip:</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>Sürüm:</translation>
    </message>
    <message>
        <source>Copyright: </source>
        <translation>Telif Hakkı:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Açıklama:</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Aynı sürüm yüklü</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Başarıyla yüklendi</translation>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation>Başarıyla Kaldırıldı</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Diğer sürüm yüklü: %1</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
</context>
</TS>

==> deepin-font-installer_1.1.orig.tar.xz: deepin-font-installer-1.1/deepin-font-installer/translations/deepin-font-installer_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>HomePage</name>
    <message>
        <source>Drag font file here</source>
        <translation>Yazı tipi dosyasını sürükleyip buraya bırakın</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Dosya seçin</translation>
    </message>
</context>
<context>
    <name>ListItem</name>
    <message>
        <source>Installed</source>
        <translation>Kurulmuş</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Başka bir sürüm kurulmuş: %1</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Kuruluyor</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Aynı sürüm kurulmuş</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Deepin Yazı Tipi Kurucu</translation>
    </message>
    <message>
        <source>Deepin Font Installer is used to install and uninstall font file for users with bulk install function.</source>
        <translation>Deepin Yazı Tipi Kurucu, kullanıcıların yazı tipi dosyalarını tek tek ya da toplu olarak kurup kaldırmasını sağlar.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Deepin Yazı Tipi Kurucu</translation>
    </message>
    <message>
        <source>Bulk Install</source>
        <translation>Toplu Kurulum</translation>
    </message>
</context>
<context>
    <name>MultiFilePage</name>
    <message>
        <source>Install</source>
        <translation>Kur</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Kuruldu</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Yazı tipi klasörünü görüntüle</translation>
    </message>
    <message>
        <source>Refreshing font cache, please wait...</source>
        <translation>Yazı tipi ön belleği yenileniyor, lütfen bekleyin...</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Bilinmiyor</translation>
    </message>
</context>
<context>
    <name>SingleFilePage</name>
    <message>
        <source>Install</source>
        <translation>Kur</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Yeniden Kur</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Yazı tipi klasörünü görüntüle</translation>
    </message>
    <message>
        <source>Style: </source>
        <translation>Biçem:</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Tür:</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>Sürüm:</translation>
    </message>
    <message>
        <source>Copyright: </source>
        <translation>Telif Hakkı:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Açıklama:</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Aynı sürüm kurulmuş</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Kuruldu</translation>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation>Kaldırıldı</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Başka bir sürüm kurulmuş: %1</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
</context>
</TS>
